@@ -29,17 +29,17 @@
 #ifndef FTPATHS_H
 #define FTPATHS_H
 
-#define FT_PATH_CFG_MAP             "/usr/local/var/cfg/map.cfg"
-#define FT_PATH_CFG_TAG             "/usr/local/var/cfg/tag.cfg"
-#define FT_PATH_CFG_FILTER          "/usr/local/var/cfg/filter.cfg"
-#define FT_PATH_CFG_STAT            "/usr/local/var/cfg/stat.cfg"
-#define FT_PATH_CFG_MASK            "/usr/local/var/cfg/mask.cfg"
-#define FT_PATH_CFG_XLATE           "/usr/local/var/cfg/xlate.cfg"
+#define FT_PATH_CFG_MAP             "/var/flow-tools/cfg/map.cfg"
+#define FT_PATH_CFG_TAG             "/var/flow-tools/cfg/tag.cfg"
+#define FT_PATH_CFG_FILTER          "/var/flow-tools/cfg/filter.cfg"
+#define FT_PATH_CFG_STAT            "/var/flow-tools/cfg/stat.cfg"
+#define FT_PATH_CFG_MASK            "/var/flow-tools/cfg/mask.cfg"
+#define FT_PATH_CFG_XLATE           "/var/flow-tools/cfg/xlate.cfg"
 
-#define FT_PATH_SYM_IP_PROT         "/usr/local/var/sym/ip-prot.sym"
-#define FT_PATH_SYM_IP_TYPE         "/usr/local/var/sym/ip-type.sym"
-#define FT_PATH_SYM_TCP_PORT        "/usr/local/var/sym/tcp-port.sym"
-#define FT_PATH_SYM_ASN             "/usr/local/var/sym/asn.sym"
-#define FT_PATH_SYM_TAG             "/usr/local/var/sym/tag.sym"
+#define FT_PATH_SYM_IP_PROT         "/var/flow-tools/sym/ip-prot.sym"
+#define FT_PATH_SYM_IP_TYPE         "/var/flow-tools/sym/ip-type.sym"
+#define FT_PATH_SYM_TCP_PORT        "/var/flow-tools/sym/tcp-port.sym"
+#define FT_PATH_SYM_ASN             "/var/flow-tools/sym/asn.sym"
+#define FT_PATH_SYM_TAG             "/var/flow-tools/sym/tag.sym"
 
 #endif /* FTPATHS_H */
